AdminLTE 3 | Widgets

# Widgets

##### Info Box

Messages 1,410
Bookmarks 410
Uploads 13,648
Likes 93,139

##### Info Box With `bg-*`

Bookmarks 41,410
70% Increase in 30 Days
Likes 41,410
70% Increase in 30 Days
Events 41,410
70% Increase in 30 Days
Comments 41,410
70% Increase in 30 Days

##### Info Box With `bg-gradient-*`

Bookmarks 41,410
70% Increase in 30 Days
Likes 41,410
70% Increase in 30 Days
Events 41,410
70% Increase in 30 Days
Comments 41,410
70% Increase in 30 Days

##### Small Box

### 150

New Orders

More info

### 53%

Bounce Rate

More info

### 44

User Registrations

More info

### 65

Unique Visitors

More info

### 150

New Orders

More info

### 53%

Bounce Rate

More info

#### Cards

##### Abilities

### Expandable

The body of the card

### Collapsable

The body of the card

### Removable

The body of the card

### Maximizable

The body of the card

### Card Refresh

The body of the card
The body of the card after card refresh

### All together

The body of the card

### Loading state

The body of the card

### Loading state (dark)

The body of the card

##### Colors Variations

### Primary Outline

The body of the card

### Success Outline

The body of the card

### Warning Outline

The body of the card

### Danger Outline

The body of the card

### Primary Outline

The body of the card

### Success Outline

The body of the card

### Warning Outline

The body of the card

### Danger Outline

The body of the card

### Primary

The body of the card

### Success

The body of the card

### Warning

The body of the card

### Danger

The body of the card

### Primary Gradient

The body of the card

### Success Gradient

The body of the card

### Warning Gradient

The body of the card

### Danger Gradient

The body of the card

#### Direct Chat

3
Alexander Pierce 23 Jan 2:00 pm
Is this template really for free? That's unbelievable!
Sarah Bullock 23 Jan 2:05 pm
You better believe it!

- Count Dracula 2/28/2015 How have you been? I was...

### Direct Chat

3
Alexander Pierce 23 Jan 2:00 pm
Is this template really for free? That's unbelievable!
Sarah Bullock 23 Jan 2:05 pm
You better believe it!

- Count Dracula 2/28/2015 How have you been? I was...

### Direct Chat

3
Alexander Pierce 23 Jan 2:00 pm
Is this template really for free? That's unbelievable!
Sarah Bullock 23 Jan 2:05 pm
You better believe it!

- Count Dracula 2/28/2015 How have you been? I was...

### Direct Chat

3
Alexander Pierce 23 Jan 2:00 pm
Is this template really for free? That's unbelievable!
Sarah Bullock 23 Jan 2:05 pm
You better believe it!

- Count Dracula 2/28/2015 How have you been? I was...

### Social Widgets

### Nadia Carmichael

##### Lead Developer

### Alexander Pierce

##### Founder & CEO

### Elizabeth Pierce

##### Web Designer

Jonathan Burke Jr. Shared publicly - 7:30 PM Today

I took this photo this morning. What do you guys think?

127 likes - 3 comments
Jonathan Burke Jr. Shared publicly - 7:30 PM Today

Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at

the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth.

#### Lorem ipsum text generator

Description about the attachment can be placed here. Lorem Ipsum is simply dummy text of the printing and typesetting industry... more
45 likes - 2 comments